==> m-tx_0.30a.orig.tar.gz: m-tx-0.30a.orig/doc/netsoos1.ex <==
%%%%%%%%%%%%%%%%%
%
% netsoos1.tex
%
%%%%%%%%%%%%%%%%
\normalmusicsize%
\tracingstats=2\relax
\hsize=539pt
\vsize=740pt
\def\nbinstruments{2}
\setstaffs11
\setclef16
\setname1{ }
\setstaffs21
\setclef20
\setname2{ }
\generalsignature{ 2}%
\generalmeter{\meterfrac{3}{4}}%
\parindent 0pt
\elemskip1pt\afterruleskip1.000pt\beforeruleskip0pt\relax
\stafftopmarg0pt\staffbotmarg5\Interligne\interstaff{10}\relax
\setinterinstrument1{9\Interligne}%
\grouptop12\groupbottom11%
\setsize2{\normalvalue}%
\setsongraise2{0\internote}%
\startpiece\addspace\afterruleskip%            
\setlyrics{21}{ge-trek tot U deur-boor-de sy, O Lam van God, ek kom.}%
\setlyrics{22}{Op U be-lof-te steun ek bly; O Lam van God, ek kom.}%
\setlyrics{23}{Dan wy ek my vir e-wig, Heer; O Lam van God, ek kom.}%
\assignlyrics2{21,22,23}%
\auxlyr{\assignlyrics2{}}%
\assignlyrics1{}%
\auxlyr{\assignlyrics1{}}%
\znotes&\zcharnote{16}{\titles{2.0}{}{0}{}{0}{}{0}}\en%
% bar  1
\def\NOTes{\vnotes2.83\elemskip}%
\def\NOTesp{\vnotes3.46\elemskip}%
\def\NOTEs{\vnotes4.00\elemskip}%
\def\NOTEsp{\vnotes4.90\elemskip}%
\NOTes\ql{'E}\ql E\ql G\nextvoice\qu{''B}\qu B\bigfl B\qu B&\ql g\ql g%
\ql e\nextvoice\nolyr\qu{'b}\nolyr\qu b\nolyr\qu c\en%
% bar  2
\xbar
\NOTEs\hl{'F}\nextvoice\hu{''A}&\hl d\nextvoice\nolyr\hu{'d}\en%
\NOTes\ql{'F}\nextvoice\qu{''A}&\ql d\nextvoice\nolyr\qu{'a}\en%
% bar  3
\xbar
\NOTEs\hl{'E}\nextvoice\hu{''B}&\hl d\nextvoice\nolyr\hu g\en%
\NOTes\ql{'A}\nextvoice\qu{''A}&\ql c\nextvoice\nolyr\qu{'a}\en%
% bar  4
\xbar
\NOTEs\hl{'D}\nextvoice\hu{''A}&\hl d\nextvoice\nolyr\hu f\en%
\NOTes\ql{'D}\nextvoice\qu{''A}&\ql d\nextvoice\nolyr\qu f\en%
% bar  5
\xbar
\NOTEs\hl{'D}\nextvoice\bigsh{'G}\hu G&\hl b\nextvoice\nolyr\hu e\en%
\NOTes\ql{'C}\nextvoice\qu{''A}&\ql e\nextvoice\nolyr\qu{'a}\en%
% bar  6
\xbar
\NOTes\islurd8{'B}\ql B\ts8E{-.8}\ql E\ql E\nextvoice\hu{''A}\sk%
\bigsh{`G}\qu G&\beginmel\islurd8f\ql f\endmel\ts8e{-.8}\ql e\ql d%
\nextvoice\nolyr\isu8{'d}{.8}\qu d\nolyr\tslur8c\qu c\nolyr\qu b\en%
\let\Endpiece=\endpiece%
% bar  7
\xbar
\NOTEsp\hlp{''A}\nextvoice\hup{''A}&\hlp c\nextvoice\nolyr\hup{'a}\en%
\Endpiece

==> m-tx_0.52.orig.tar.gz: m-tx-0.52/doc/netsoos1.ex <==
%%%%%%%%%%%%%%%%%
%
% netsoos1.tex
%
%%%%%%%%%%%%%%%%
\def\Lrp#1{\centerbar{\liftpause{#1}}}
\normalmusicsize%
\tracingstats=2\relax
\hsize=539pt
\vsize=740pt
\def\nbinstruments{2}
\setstaffs11
\setclef16
\setname1{ }
\setstaffs21
\setclef20
\setname2{ }
\generalsignature{ 2}%
\generalmeter{\meterfrac{3}{4}}%
\parindent 0pt
\elemskip1pt\afterruleskip1.000pt\beforeruleskip0pt\relax
\stafftopmarg0pt\staffbotmarg5\Interligne\interstaff{10}\relax
\setinterinstrument1{9\Interligne}%
\grouptop12\groupbottom11%
\startpiece\addspace\afterruleskip%
\setlyrics{21}{ge-trek tot U deur-boor-de sy, O Lam van God, ek kom.}%
\setlyrics{22}{Op U be-lof-te steun ek bly; O Lam van God, ek kom.}%
\setlyrics{23}{Dan wy ek my vir e-wig, Heer; O Lam van God, ek kom.}%
\assignlyrics2{21,22,23}%
\znotes&\zcharnote{16}{\titles{2.0}{}{0}{}{0}{}{0}}\en%
% bar  1
\def\NOTes{\vnotes2.83\elemskip}%
\def\NOTEs{\vnotes4.00\elemskip}%
\def\NOTEsp{\vnotes4.90\elemskip}%
\NOTes\ql{'E}\ql E\ql G\nextvoice\qu{''B}\qu B\bigfl B\qu B&\ql g\ql g%
\ql e\nextvoice\qu{'b}\qu b\qu c\en%
% bar  2
\xbar
\NOTEs\hl{'F}\nextvoice\hu{''A}&\hl d\nextvoice\hu{'d}\en%
\NOTes\ql{'F}\nextvoice\qu{''A}&\ql d\nextvoice\qu{'a}\en%
% bar  3
\xbar
\NOTEs\hl{'E}\nextvoice\hu{''B}&\hl d\nextvoice\hu g\en%
\NOTes\ql{'A}\nextvoice\qu{''A}&\ql c\nextvoice\qu{'a}\en%
% bar  4
\xbar
\NOTEs\hl{'D}\nextvoice\hu{''A}&\hl d\nextvoice\hu f\en%
\NOTes\ql{'D}\nextvoice\qu{''A}&\ql d\nextvoice\qu f\en%
% bar  5
\xbar
\NOTEs\hl{'D}\nextvoice\bigsh{'G}\hu G&\hl b\nextvoice\hu e\en%
\NOTes\ql{'C}\nextvoice\qu{''A}&\ql e\nextvoice\qu{'a}\en%
% bar  6
\xbar
\NOTes\islurd8{'B}\ql B\ts8E{-.8}\ql E\ql E\nextvoice\hu{''A}\sk%
\bigsh{`G}\qu G&\beginmel\islurd8f\ql f\endmel\ts8e{-.8}\ql e\ql d%
\nextvoice\isu8{'d}{.8}\qu d\tslur8c\qu c\qu b\en%
\let\Endpiece=\endpiece%
% bar  7
\xbar
\NOTEsp\hlp{''A}\nextvoice\hup{''A}&\hlp c\nextvoice\hup{'a}\en%
\Endpiece
